Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorClément Foucault <foucault.clem@gmail.com>2018-07-18 01:12:21 +0300
committerClément Foucault <foucault.clem@gmail.com>2018-07-18 12:49:15 +0300
commit8cd7828792419fb4eac9a2a477968535b4c71535 (patch)
tree8fc733149fe07b7d9edd4b8b1e709519b4481887 /source/blender/gpu/GPU_context.h
parent247ad2034de2c33a6d9cb7d3b6f1ef7ffa5b859d (diff)
GWN: Port to GPU module: Replace GWN prefix by GPU
Diffstat (limited to 'source/blender/gpu/GPU_context.h')
-rw-r--r--source/blender/gpu/GPU_context.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/source/blender/gpu/GPU_context.h b/source/blender/gpu/GPU_context.h
index 0cedc109645..5f63c408801 100644
--- a/source/blender/gpu/GPU_context.h
+++ b/source/blender/gpu/GPU_context.h
@@ -23,14 +23,14 @@
* ***** END GPL LICENSE BLOCK *****
*/
-/** \file blender/gpu/gwn_context.h
+/** \file blender/gpu/GPU_context.h
* \ingroup gpu
*
* This interface allow Gawain to manage VAOs for mutiple context and threads.
*/
-#ifndef __GWN_CONTEXT_H__
-#define __GWN_CONTEXT_H__
+#ifndef __GPU_CONTEXT_H__
+#define __GPU_CONTEXT_H__
#ifdef __cplusplus
extern "C" {
@@ -40,16 +40,16 @@ extern "C" {
#include "GPU_batch.h"
#include "GPU_shader_interface.h"
-typedef struct Gwn_Context Gwn_Context;
+typedef struct GPUContext GPUContext;
-Gwn_Context* GWN_context_create(void);
-void GWN_context_discard(Gwn_Context*);
+GPUContext* GPU_context_create(void);
+void GPU_context_discard(GPUContext*);
-void GWN_context_active_set(Gwn_Context*);
-Gwn_Context* GWN_context_active_get(void);
+void GPU_context_active_set(GPUContext*);
+GPUContext* GPU_context_active_get(void);
#ifdef __cplusplus
}
#endif
-#endif /* __GWN_CONTEXT_H__ */
+#endif /* __GPU_CONTEXT_H__ */
@@ -23,14 +23,14 @@
* \ingroup gpu
*
- * This interface allow Gawain to manage VAOs for mutiple context and threads.
+ * This interface allow GPU to manage VAOs for mutiple context and threads.
*/